==> log4cxx_0.12.1.orig.tar.gz: apache-log4cxx-0.12.1/src/site/markdown/community/issue-tracking.md <==
Issue Tracking {#issue-tracking}
===
<!--
 Note: License header cannot be first, as doxygen does not generate
 cleanly if it before the '==='
-->
<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->
# Overview

This project uses [JIRA](https://www.atlassian.com/software/jira), a J2EE-based issue tracking
and project management application.

# Issue Tracking

*Bugs* and *feature requests* should be submitted to the following issue tracking system
for this project.

https://issues.apache.org/jira/browse/LOGCXX

*Please don't just open bugs only because things don't work for you*, some issues simply
aren't bugs in the code base of the project or it's build tools, but may have a lot of
different other reasons. If things don't work for you and you need some help, please subscribe
to the [users mailing list] and describe
the issue you have, the more detailed the better. The mailing list is a far better place to
discuss things than JIRA, besides that there are more users than developers of the project and
issues created in JIRA are only forwarded to the latter. There's always the chance to create an
issue in JIRA later, hopefully with a specific explanation of the problem and even a solution
already.

As a rule of thumb, if you already digged through the code and found a problem in it or its
build tools, feel free to directly create a bug in [JIRA](https://issues.apache.org/jira/browse/LOGCXX).
But if things really only don't work and you don't have any clue why, please use the [users mailing list]
instead.

Thanks!

[users mailing list]:@ref mailing-lists

==> log4cxx_1.0.0.orig.tar.gz: apache-log4cxx-1.0.0/src/site/markdown/community/issue-tracking.md <==
Issue Tracking {#issue-tracking}
===
<!--
 Note: License header cannot be first, as doxygen does not generate
 cleanly if it before the '==='
-->
<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->
# Overview

This project uses [JIRA](https://www.atlassian.com/software/jira), a J2EE-based issue tracking
and project management application. Issues may also be filed through GitHub.

# Issue Tracking

*Bugs* and *feature requests* should be submitted to the following issue tracking system
for this project.

https://issues.apache.org/jira/browse/LOGCXX

If you do not have a JIRA account, you may email private@logging.apache.org due to the
Apache Software Foundation restricting signups([more information](https://infra.apache.org/jira-guidelines.html#who)).

Issues may also be filed via the github mirror:

https://github.com/apache/logging-log4cxx/issues

*Please don't just open bugs only because things don't work for you*, some issues simply
aren't bugs in the code base of the project or it's build tools, but may have a lot of
different other reasons. If things don't work for you and you need some help, please subscribe
to the [users mailing list] and describe
the issue you have, the more detailed the better. The mailing list is a far better place to
discuss things than JIRA, besides that there are more users than developers of the project and
issues created in JIRA are only forwarded to the latter. There's always the chance to create an
issue in JIRA later, hopefully with a specific explanation of the problem and even a solution
already.

As a rule of thumb, if you already digged through the code and found a problem in it or its
build tools, feel free to directly create a bug in [JIRA](https://issues.apache.org/jira/browse/LOGCXX).
But if things really only don't work and you don't have any clue why, please use the [users mailing list]
instead.

Thanks!

[users mailing list]:@ref mailing-lists
